@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,8 +31,6 @@
 
 #include <string.h>
 #include <stdio.h>
-#ifndef GCC
-#endif
 
 #include <svl/itempool.hxx>
 #include "whassert.hxx"
@@ -82,7 +81,7 @@ const SfxPoolItem* SfxItemPool::GetPoolDefaultItem( USHORT nWhich ) const
 
 // -----------------------------------------------------------------------
 
-inline FASTBOOL SfxItemPool::IsItemFlag_Impl( USHORT nPos, USHORT nFlag ) const
+inline bool SfxItemPool::IsItemFlag_Impl( USHORT nPos, USHORT nFlag ) const
 {
     USHORT nItemFlag = pItemInfos[nPos]._nFlags;
     return nFlag == (nItemFlag & nFlag);
@@ -90,7 +89,7 @@ inline FASTBOOL SfxItemPool::IsItemFlag_Impl( USHORT nPos, USHORT nFlag ) const
 
 // -----------------------------------------------------------------------
 
-FASTBOOL SfxItemPool::IsItemFlag( USHORT nWhich, USHORT nFlag ) const
+bool SfxItemPool::IsItemFlag( USHORT nWhich, USHORT nFlag ) const
 {
     for ( const SfxItemPool *pPool = this; pPool; pPool = pPool->pSecondary )
     {
@@ -126,7 +125,7 @@ SfxItemPool::SfxItemPool
 #ifndef TF_POOLABLE
     USHORT*             pSlotIdArray,   /* Zuordnung von Slot-Ids zu Which-Ids */
 #endif
-    FASTBOOL            bLoadRefCounts  /* Ref-Counts mitladen oder auf 1 setzen */
+    bool                bLoadRefCounts  /* Ref-Counts mitladen oder auf 1 setzen */
 )
 
 /*  [Beschreibung]
@@ -187,7 +186,7 @@ SfxItemPool::SfxItemPool
     pImp->nInitRefCount = 1;
     pImp->nVerStart = nStart;
     pImp->nVerEnd = nEnd;
-    pImp->bInSetItem = FALSE;
+    pImp->bInSetItem = false;
     pImp->nStoringStart = nStartWhich;
     pImp->nStoringEnd = nEndWhich;
 
@@ -246,7 +245,7 @@ SfxItemPool::SfxItemPool
     pImp->nInitRefCount = 1;
     pImp->nVerStart = rPool.pImp->nVerStart;
     pImp->nVerEnd = rPool.pImp->nVerEnd;
-    pImp->bInSetItem = FALSE;
+    pImp->bInSetItem = false;
     pImp->nStoringStart = nStart;
     pImp->nStoringEnd = nEnd;
 
@@ -1171,3 +1170,4 @@ void SfxItemPool::SetFileFormatVersion( USHORT nFileFormatVersion )
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
