@@ -344,12 +344,8 @@ BOOL EnhWMFReader::ReadEnhWMF()
     sal_Bool	bFlag, bStatus = ReadHeader();
     sal_Bool    bHaveDC = false;
 
-#ifdef UNX
-    static sal_Bool bEnableEMFPlus = ( getenv( "EMF_PLUS_DISABLE" ) == NULL );
-#else
-    // TODO: make it possible to disable emf+ on windows
-    static sal_Bool bEnableEMFPlus = sal_True;
-#endif
+    // disable EMF+ temporarily on all platforms
+    static sal_Bool bEnableEMFPlus = sal_False;
 
     while( bStatus && nRecordCount-- )
     {
