@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -35,14 +36,10 @@
 
 #define _SV_SALINST_CXX
 
-#ifndef _VOS_MUTEX_HXX
-#include <vos/mutex.hxx>
-#endif
+#include <vcl/solarmutex.hxx>
 #include <tools/debug.hxx>
 
-#ifndef _SV_SALIDS_HRC
 #include <salids.hrc>
-#endif
 #include <vcl/salatype.hxx>
 #include <saldata.hxx>
 #include <salinst.h>
@@ -85,7 +82,7 @@ MRESULT EXPENTRY SalComWndProc( HWND hWnd, ULONG nMsg, MPARAM nMP1, MPARAM nMP2
 
 // =======================================================================
 
-class SalYieldMutex : public vos::OMutex
+class SalYieldMutex : public vcl::SolarMutexObject
 {
 public:
     Os2SalInstance*			mpInstData;
@@ -115,7 +112,7 @@ SalYieldMutex::SalYieldMutex( Os2SalInstance* pInstData )
 
 void SalYieldMutex::acquire()
 {
-    OMutex::acquire();
+    SolarMutexObject::acquire();
     mnCount++;
     mnThreadId = GetCurrentThreadId();
 }
@@ -126,7 +123,7 @@ void SalYieldMutex::release()
 {
     ULONG nThreadId = GetCurrentThreadId();
     if ( mnThreadId != nThreadId )
-        OMutex::release();
+        SolarMutexObject::release();
     else
     {
         SalData* pSalData = GetSalData();
@@ -139,13 +136,13 @@ void SalYieldMutex::release()
                     WinPostMsg( mpInstData->mhComWnd, SAL_MSG_RELEASEWAITYIELD, 0, 0 );
                 mnThreadId = 0;
                 mnCount--;
-                OMutex::release();
+                SolarMutexObject::release();
                 mpInstData->mpSalWaitMutex->release();
             }
             else
             {
                 mnCount--;
-                OMutex::release();
+                SolarMutexObject::release();
             }
         }
         else
@@ -153,7 +150,7 @@ void SalYieldMutex::release()
             if ( mnCount == 1 )
                 mnThreadId = 0;
             mnCount--;
-            OMutex::release();
+            SolarMutexObject::release();
         }
     }
 }
@@ -162,7 +159,7 @@ void SalYieldMutex::release()
 
 sal_Bool SalYieldMutex::tryToAcquire()
 {
-    if ( OMutex::tryToAcquire() )
+    if ( SolarMutexObject::tryToAcquire() )
     {
         mnCount++;
         mnThreadId = GetCurrentThreadId();
@@ -496,7 +493,7 @@ Os2SalInstance::Os2SalInstance()
 {
     mhComWnd				= 0;
     mpSalYieldMutex			= new SalYieldMutex( this );
-    mpSalWaitMutex			= new vos::OMutex;
+    mpSalWaitMutex			= new osl::Mutex;
     mnYieldWaitCount         = 0;
     mpSalYieldMutex->acquire();
     ::tools::SolarMutex::SetSolarMutex( mpSalYieldMutex );
@@ -515,7 +512,7 @@ Os2SalInstance::~Os2SalInstance()
 
 // -----------------------------------------------------------------------
 
-vos::IMutex* Os2SalInstance::GetYieldMutex()
+osl::SolarMutex* Os2SalInstance::GetYieldMutex()
 {
     return mpSalYieldMutex;
 }
@@ -563,7 +560,7 @@ static void ImplSalYield( BOOL bWait, BOOL bHandleAllCurrentEvents )
         else
             bQuit = true;
     }
-    
+
     if (bQuit)
     {
         ImplSalYieldMutexAcquireWithWait();
@@ -594,7 +591,7 @@ void Os2SalInstance::Yield( bool bWait, bool bHandleAllCurrentEvents )
     }
     if ( pSalData->mnAppThreadId != nCurThreadId )
     {
-        // #97739# A SendMessage call blocks until the called thread (here: the main thread) 
+        // #97739# A SendMessage call blocks until the called thread (here: the main thread)
         // returns. During a yield however, messages are processed in the main thread that might
         // result in a new message loop due to opening a dialog. Thus, SendMessage would not
         // return which will block this thread!
@@ -664,7 +661,7 @@ MRESULT EXPENTRY SalComWndProc( HWND hWnd, ULONG nMsg,
             return 0;
         case SAL_MSG_DESTROYHWND:
             //We only destroy the native window here. We do NOT destroy the SalFrame contained
-            //in the structure (GetWindowPtr()). 
+            //in the structure (GetWindowPtr()).
             if (WinDestroyWindow((HWND)nMP2) == 0)
             {
                 OSL_ENSURE(0, "DestroyWindow failed!");
@@ -788,7 +785,7 @@ void Os2SalInstance::DestroyFrame( SalFrame* pFrame )
 
 SalObject* Os2SalInstance::CreateObject( SalFrame* pParent,
                                          SystemWindowData* /*pWindowData*/, // SystemWindowData meaningless on Windows
-                                         BOOL /*bShow*/ ) 
+                                         BOOL /*bShow*/ )
 {
     // Um auf Main-Thread umzuschalten
     return (SalObject*)WinSendMsg( mhComWnd, SAL_MSG_CREATEOBJECT, 0, (MPARAM)pParent );
@@ -836,7 +833,7 @@ class Os2ImeStatus : public SalI18NImeStatus
   public:
     Os2ImeStatus() {}
     virtual ~Os2ImeStatus() {}
-    
+
     // asks whether there is a status window available
     // to toggle into menubar
     virtual bool canToggle() { return false; }
@@ -861,3 +858,4 @@ SalSession* Os2SalInstance::CreateSalSession()
     return NULL;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
