@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,9 +32,7 @@
 #define _SV_SALGDI2_CXX
 #include <salbmp.h>
 #include <saldata.hxx>
-#ifndef _SV_SALIDS_HRC
 #include <salids.hrc>
-#endif
 #include <salgdi.h>
 #include <salvd.h>
 #include <vcl/salbtype.hxx>
@@ -784,3 +783,4 @@ void Os2SalGraphics::invert( ULONG nPoints, const SalPoint* pPtAry, SalInvert nF
     }
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
