@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -35,9 +36,7 @@
 #include <vcl/outdev.hxx>
 #include <vcl/impbmp.hxx>
 #include <vcl/salbmp.hxx>
-#ifndef _SV_RC_H
 #include <tools/rc.h>
-#endif
 #include <vcl/bitmap.hxx>
 #include <vcl/bitmapex.hxx>
 #include <vcl/svapp.hxx>
@@ -1966,3 +1965,5 @@ bool Bitmap::GetSystemData( BitmapSystemData& rData ) const
     
     return bRet;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
