@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -2363,11 +2364,6 @@ ULONG SVMConverter::ImplWriteActions( SvStream& rOStm, GDIMetaFile& rMtf,
             }
             break;
 
-#if 0
-            case( META_OVERLINECOLOR_ACTION ):
-            break;
-#endif
-
             case( META_TEXTLINE_ACTION ):
             {
                 const MetaTextLineAction*	pA = (MetaTextLineAction*) pAction;
@@ -2514,3 +2510,5 @@ ULONG SVMConverter::ImplWriteActions( SvStream& rOStm, GDIMetaFile& rMtf,
 
     return nCount;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
