@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -36,9 +37,7 @@
 #include <vcl/svapp.hxx>
 #include <vcl/wrkwin.hxx>
 #include <vcl/virdev.hxx>
-#ifndef _SV_VECTORIZ_HXX
 #include <impvect.hxx>
-#endif
 
 // -----------
 // - Defines -
@@ -1202,3 +1201,5 @@ BOOL ImplVectorizer::ImplIsUp( ImplVectMap* pMap, long nY, long nX ) const
     else
         return FALSE;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
