@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,9 +32,7 @@
 #define ENABLE_BYTESTRING_STREAM_OPERATORS
 #include <list>
 
-#ifndef _SV_SVSYS_HXX
 #include <svsys.h>
-#endif
 #include <vcl/salinst.hxx>
 #include <vcl/salgdi.hxx>
 #include <vcl/salptype.hxx>
@@ -1479,3 +1478,5 @@ void Printer::updatePrinters()
             delete pNewList;
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
