@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -29,9 +30,7 @@
 #include "precompiled_vcl.hxx"
 #include <tools/debug.hxx>
 
-#ifndef _SV_SVSYS_HXX
 #include <svsys.h>
-#endif
 #include <vcl/salframe.hxx>
 #include <vcl/svdata.hxx>
 #include <vcl/svapp.hxx>
@@ -773,7 +772,7 @@ void SystemWindow::SetWindowStateData( const WindowStateData& rData )
                 BOOL bWrapped = FALSE;
                 while( pWin )
                 {
-                    if( !pWin->ImplIsRealParentPath( this ) && 
+                    if( !pWin->ImplIsRealParentPath( this ) && ( pWin != this ) &&
                         pWin->ImplGetWindow()->IsTopWindow() && pWin->mpWindowImpl->mbReallyVisible )
                     {
                         SalFrameGeometry g = pWin->mpWindowImpl->mpFrame->GetGeometry();
@@ -1080,7 +1079,14 @@ unsigned int SystemWindow::GetScreenNumber() const
 
 // -----------------------------------------------------------------------
 
-void SystemWindow::SetScreenNumber( unsigned int nScreen)
+void SystemWindow::SetScreenNumber(unsigned int nScreen)
 {
     mpWindowImpl->mpFrame->SetScreenNumber( nScreen );
 }
+
+void SystemWindow::SetApplicationID(const rtl::OUString &rApplicationID)
+{
+    mpWindowImpl->mpFrame->SetApplicationID(rApplicationID);
+}
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
