@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -56,10 +57,8 @@
 #include <sys/time.h>
 #include <unistd.h>
 #endif
-#include <vos/process.hxx>
-#ifndef _VOS_MUTEX_HXX
-#include <vos/mutex.hxx>
-#endif
+#include <osl/process.h>
+#include <osl/mutex.hxx>
 
 #include "Xproto.h"
 #include <saldisp.hxx>
@@ -68,11 +67,8 @@
 #include <salframe.h>
 #include <osl/signal.h>
 #include <osl/thread.h>
-#include <osl/process.h>
 #include <rtl/strbuf.hxx>
-#ifndef _RTL_BOOTSTRAP_HXX
 #include <rtl/bootstrap.hxx>
-#endif
 
 #include <tools/debug.hxx>
 #include <sm.hxx>
@@ -400,20 +396,20 @@ void SalXLib::Init()
      *  o  $DISPLAY environment variable
      *  o  default display
      */
-    
+
     Display *pDisp = NULL;
 
     // is there a -display command line parameter?
-    vos::OExtCommandLine aCommandLine;
-    sal_uInt32 nParams = aCommandLine.getCommandArgCount();
+
+    sal_uInt32 nParams = osl_getCommandArgCount();
     rtl::OUString aParam;
     rtl::OString aDisplay;
-    for (USHORT i=0; i<nParams; i++) 
+    for (USHORT i=0; i<nParams; i++)
     {
-        aCommandLine.getCommandArg(i, aParam);
+        osl_getCommandArg(i, &aParam.pData);
         if (aParam.equalsAscii("-display"))
         {
-            aCommandLine.getCommandArg(i+1, aParam);
+            osl_getCommandArg(i+1, &aParam.pData);
             aDisplay = rtl::OUStringToOString(
                    aParam, osl_getThreadTextEncoding());
 
@@ -421,20 +417,18 @@ void SalXLib::Init()
             {
                 /*
                  * if a -display switch was used, we need
-                 * to set the environment accoringly since 
-                 * the clipboard build another connection 
+                 * to set the environment accoringly since
+                 * the clipboard build another connection
                  * to the xserver using $DISPLAY
                  */
-                const char envpre[] = "DISPLAY=";
-                char *envstr = new char[sizeof(envpre)+aDisplay.getLength()];
-                snprintf(envstr, sizeof(envpre)+aDisplay.getLength(), "DISPLAY=%s", aDisplay.getStr());
-                putenv(envstr);
+                 rtl::OUString envVar(RTL_CONSTASCII_USTRINGPARAM("DISPLAY"));
+                 osl_setEnvironment(envVar.pData, aParam.pData);
             }
             break;
         }
     }
 
-    if (!pDisp && !aDisplay.getLength()) 
+    if (!pDisp && !aDisplay.getLength())
     {
         // Open $DISPLAY or default...
         char *pDisplay = getenv("DISPLAY");
@@ -869,3 +863,5 @@ rtl::OString X11SalData::getFrameResName( SalExtStyle nStyle )
     
     return aBuf.makeStringAndClear();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
