@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -384,22 +385,6 @@ QueryCharWidth16( Display* pDisplay, XLIB_Font nFontID, sal_MultiByte nChar,
     return CharExists( &aBoundingBox ) ? aBoundingBox.width : nDefaultWidth;
 }
 
-#if 0
-// currently not used
-static sal_Size
-QueryCharWidth8( XFontStruct* pXFontStruct, sal_Char nChar,
-    sal_Size nDefaultWidth )
-{
-    int nDirection, nFontAscent, nFontDescent;
-    XCharStruct aBoundingBox;
-
-    XTextExtents( pXFontStruct, &nChar, 1,
-        &nDirection, &nFontAscent, &nFontDescent, &aBoundingBox );
-
-    return CharExists( &aBoundingBox ) ? aBoundingBox.width : nDefaultWidth;
-}
-#endif
-
 sal_Size
 ExtendedFontStruct::GetDefaultWidth()
 {
@@ -778,3 +763,5 @@ void X11FontLayout::DrawText( SalGraphics& rSalGraphics ) const
 }
 
 // =======================================================================
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
